@@ -38,10 +38,12 @@
 #include "Params/FilterParams.h"
 #include "Params/Presets.h"
 
+class SynthEngine;
+
 class EffectMgr : public Presets
 {
     public:
-        EffectMgr(const bool insertion_);
+        EffectMgr(const bool insertion_, SynthEngine *_synth);
         ~EffectMgr();
 
         void add2XML(XMLwrapper *xml);
@@ -65,6 +67,8 @@ class EffectMgr : public Presets
         void seteffectpar_nolock(int npar, unsigned char value);
         unsigned char geteffectpar(int npar);
 
+        SynthEngine *getSynthEngine() {return synth;}
+
         float *efxoutl, *efxoutr;
         bool insertion; // the effect is connected as insertion effect (or not)
 
