@@ -74,7 +74,7 @@ void Phaser::analog_setup()
     Rconst    = 1.0f + Rmx; // Handle parallel resistor relationship
     C         = 0.00000005f; // 50 nF
     CFs       = 2.0f * synth->samplerate_f * C;
-    invperiod = 1.0f / synth->buffersize_f;
+    invperiod = 1.0f / synth->p_all_buffersize_f;
 }
 
 
@@ -144,7 +144,7 @@ void Phaser::AnalogPhase(float *smpsl, float *smpsr)
     oldlgain = modl;
     oldrgain = modr;
 
-   for(int i = 0; i < synth->buffersize; ++i) {
+   for(int i = 0; i < synth->p_buffersize; ++i) {
         gl += diffl; // Linear interpolation between LFO samples
         gr += diffr;
 
@@ -167,8 +167,8 @@ void Phaser::AnalogPhase(float *smpsl, float *smpsr)
     }
     
     if(Poutsub) {
-        invSignal(efxoutl, synth->buffersize);
-        invSignal(efxoutr, synth->buffersize);
+        invSignal(efxoutl, synth->p_buffersize);
+        invSignal(efxoutr, synth->p_buffersize);
     }
 }
 
@@ -269,16 +269,10 @@ void Phaser::cleanup(void)
     fbl = fbr = oldlgain = oldrgain = 0.0f;
     memset(oldl, 0, sizeof(float)*Pstages * 2);
     memset(oldr, 0, sizeof(float)*Pstages * 2);
-//    for (int i = 0; i < Pstages * 2; ++i)
-//        oldl[i] = oldr[i] = 0.0f;
     memset(xn1l, 0, sizeof(float)*Pstages);
     memset(xn1r, 0, sizeof(float)*Pstages);
     memset(yn1l, 0, sizeof(float)*Pstages);
     memset(yn1r, 0, sizeof(float)*Pstages);
-//    for(int i = 0; i < Pstages; ++i) {
-//        xn1l[i] = xn1r[i] =0.0f;
-//        yn1l[i] = yn1r[i] = 0.0f;
-//    }
 }
 
 
