@@ -42,6 +42,7 @@ using namespace std;
 #include "Misc/XMLwrapper.h"
 #include "Misc/Config.h"
 #include "Misc/Bank.h"
+#include "Misc/MiscFuncs.h"
 #include "Misc/SynthEngine.h"
 
 Bank::Bank(SynthEngine *_synth) :
@@ -65,6 +66,18 @@ Bank::~Bank()
 }
 
 
+string Bank::getBankFileTitle()
+{
+    return synth->makeUniqueName("Root " + asString(currentRootID) + ", Bank " + asString(currentBankID) + " - " + getBankPath(currentRootID, currentBankID));
+}
+
+
+string Bank::getRootFileTitle()
+{
+    return synth->makeUniqueName("Root " + asString(currentRootID) + " - " + getRootPath(currentRootID));
+}
+
+
 bool Bank::readOnlyInstrument(int ninstrument)
 {
     if (readOnlyBank(currentBankID))
@@ -84,6 +97,14 @@ string Bank::getname(unsigned int ninstrument)
     return getInstrumentReference(ninstrument).name;
 }
 
+// Get the full path of an instrument from the current bank
+string Bank::getfilename(unsigned int ninstrument)
+{
+    string fname = "";
+    if (!emptyslot(ninstrument))
+        fname = getFullPath(currentRootID, currentBankID, ninstrument);
+    return fname;
+}
 
 // Get the numbered name of an instrument from the bank
 string Bank::getnamenumbered(unsigned int ninstrument)
@@ -113,7 +134,7 @@ bool Bank::setname(unsigned int ninstrument, string newname, int newslot)
     int chk = rename(getFullPath(currentRootID, currentBankID, ninstrument).c_str(), newfilepath.c_str());
     if (chk < 0)
     {
-        synth->getRuntime().Log("Bank: setName failed renaming "
+        synth->getRuntime().Log("setName failed renaming "
                     + getFullPath(currentRootID, currentBankID, ninstrument) + " -> "
                     + newfilepath + ": " + string(strerror(errno)));
         return false;
@@ -146,7 +167,7 @@ void Bank::clearslot(unsigned int ninstrument)
     int chk = remove(getFullPath(currentRootID, currentBankID, ninstrument).c_str());
     if (chk < 0)
     {
-        synth->getRuntime().Log("clearSlot: " + asString(ninstrument) + " Failed to remove "
+        synth->getRuntime().Log(asString(ninstrument) + " Failed to remove "
                      + getFullPath(currentRootID, currentBankID, ninstrument) + " "
                      + string(strerror(errno)));
     }
@@ -159,7 +180,7 @@ void Bank::savetoslot(unsigned int ninstrument, Part *part)
 {
     if (ninstrument >= BANK_SIZE)
     {
-        synth->getRuntime().Log("savetoslot: Saved " + asString(ninstrument) + ", slot > BANK_SIZE");
+        synth->getRuntime().Log("Saved " + asString(ninstrument) + ", slot > BANK_SIZE");
         return;
     }
     clearslot(ninstrument);
@@ -175,24 +196,13 @@ void Bank::savetoslot(unsigned int ninstrument, Part *part)
     {
         int chk = remove(filepath.c_str());
         if (chk < 0)
-            synth->getRuntime().Log("Bank saveToSlot failed to unlink " + filepath
+            synth->getRuntime().Log("saveToSlot failed to unlink " + filepath
                         + ", " + string(strerror(errno)));
     }
     part->saveXML(filepath);
     addtobank(currentRootID, currentBankID, ninstrument, filename, part->Pname);
 }
 
-
-// Loads the instrument from the bank
-bool Bank::loadfromslot(unsigned int ninstrument, Part *part)
-{
-    bool flag = false;
-    if (!emptyslot(ninstrument))
-        flag = part->loadXMLinstrument(getFullPath(currentRootID, currentBankID, ninstrument));
-    return flag;
-}
-
-
 bool Bank::readOnlyBank(int bankID)
 {
     const char * root = getRootPath(currentRootID).c_str();
@@ -244,7 +254,7 @@ bool Bank::setbankname(unsigned int bankID, string newname)
                      newfilepath.c_str());
     if (chk < 0)
     {
-        synth->getRuntime().Log("Bank: Failed to rename " + getBankName(bankID)
+        synth->getRuntime().Log("Failed to rename " + getBankName(bankID)
                                + " to " + newname);
         return false;
     }
@@ -326,16 +336,6 @@ bool Bank::loadbank(size_t rootID, size_t banknum)
     return true;
 }
 
-// no longer used.
-// Makes a new bank, put it on a file and makes it current bank
-/*bool Bank::newbank(string newbankdir)
-{
-    if (!newbankfile(newbankdir))
-        return false;
-    currentBankID = add_bank(newbankdir, newbankdir, currentRootID);
-    return true;
-}*/
-
 
 // Makes a new bank with known ID. Does *not* make it current
 bool Bank::newIDbank(string newbankdir, unsigned int bankID)
@@ -363,7 +363,7 @@ bool Bank::newbankfile(string newbankdir)
     int result = mkdir(newbankpath.c_str(), S_IRWXU | S_IRWXG | S_IROTH | S_IXOTH);
     if (result < 0)
     {
-        synth->getRuntime().Log("Bank: Failed to mkdir " + newbankpath);
+        synth->getRuntime().Log("Failed to mkdir " + newbankpath);
         return false;
     }
     else
@@ -389,8 +389,7 @@ bool Bank::removebank(unsigned int bankID)
             chk = remove(getFullPath(currentRootID, bankID, inst).c_str());
             if (chk < 0)
             {
-                synth->getRuntime().Log("removebank: "
-                                        + asString(inst) + " Failed to remove "
+                synth->getRuntime().Log(asString(inst) + " Failed to remove "
                                         + getFullPath(currentRootID, bankID, inst) + " "
                                         + string(strerror(errno)));
                 return false;
@@ -401,14 +400,14 @@ bool Bank::removebank(unsigned int bankID)
         chk = remove(tmp.c_str());
         if (chk < 0)
         {
-            synth->getRuntime().Log("removebank: Failed to remove bank ID file"
+            synth->getRuntime().Log("Failed to remove bank ID file"
                                     + string(strerror(errno)));
             return false;
         }
         chk = remove(getBankPath(currentRootID, bankID).c_str());
         if (chk < 0)
         {
-            synth->getRuntime().Log("removebank: Failed to remove bank"
+            synth->getRuntime().Log("Failed to remove bank"
                                     + asString(bankID) + ": "
                                     + string(strerror(errno)));
             return false;
@@ -564,7 +563,7 @@ void Bank::scanrootdir(int root_idx)
         DIR *d = opendir(chkdir.c_str());
         if (d == NULL)
         {
-            synth->getRuntime().Log("scanrootdir: Failed to open bank directory candidate " + chkdir);
+            synth->getRuntime().Log("Failed to open bank directory candidate " + chkdir);
             continue;
         }
         struct dirent *fname;
@@ -725,7 +724,6 @@ void Bank::addDefaultRootDirs()
         "/usr/share/zynaddsubfx/banks",
         "/usr/local/share/zynaddsubfx/banks",
         string(getenv("HOME")) + "/banks",
-        "../banks",
         "end"
     };
     int i = 0;
@@ -734,6 +732,7 @@ void Bank::addDefaultRootDirs()
         addRootDir(bankdirs [i]);
         ++ i;
     }
+    addRootDir(localPath("/banks"));
     rescanforbanks();
 }
 
@@ -957,6 +956,9 @@ void Bank::parseConfigFile(XMLwrapper *xml)
 {
     roots.clear();
     hints.clear();
+    size_t tmp_root = xml->getpar("root_current_ID", 0, 0, 127);
+    size_t tmp_bank = xml->getpar("bank_current_ID", 0, 0, 127);
+    
     string nodename = "BANKROOT";
     for (size_t i = 0; i < MAX_BANK_ROOT_DIRS; ++i)
     {
@@ -992,12 +994,15 @@ void Bank::parseConfigFile(XMLwrapper *xml)
 
     rescanforbanks();
 
-    setCurrentRootID(xml->getpar("root_current_ID", 0, 0, 127));
-    setCurrentBankID(xml->getpar("bank_current_ID", 0, 0, 127));
+    setCurrentRootID(tmp_root); // done this way so laoding full set
+    setCurrentBankID(tmp_bank); // doesn't change it - need to investigate!
 }
 
 void Bank::saveToConfigFile(XMLwrapper *xml)
 {
+    xml->addpar(string("root_current_ID"), currentRootID);
+    xml->addpar(string("bank_current_ID"), currentBankID);
+    
     for (size_t i = 0; i < MAX_BANK_ROOT_DIRS; i++)
     {
         if (roots.count(i) > 0 && !roots [i].path.empty())
@@ -1017,7 +1022,4 @@ void Bank::saveToConfigFile(XMLwrapper *xml)
             xml->endbranch();
         }
     }
-    xml->addpar(string("root_current_ID"), currentRootID);
-    xml->addpar(string("bank_current_ID"), currentBankID);
-
 }
