@@ -38,15 +38,7 @@ using namespace std;
 #define ROOT_SIZE 128
 #define BANK_SIZE 160
 
-// not needed anymore? #define MAX_NUM_BANKS 2000
-/*
-typedef struct {
-    string name;
-    string alias;
-    string dir;
-    int ID;
-} bankstruct_t;
-*/
+
 typedef struct _InstrumentEntry
 {
     string name;
@@ -113,6 +105,7 @@ class Bank : private MiscFuncs
         ~Bank();
         bool readOnlyInstrument(int ninstrument);
         string getname(unsigned int ninstrument);
+        string getfilename(unsigned int ninstrument);
         string getnamenumbered(unsigned int ninstrument);
         bool setname(unsigned int ninstrument, string newname, int newslot);
              // if newslot==-1 then this is ignored, else it will be put on that slot
@@ -122,7 +115,6 @@ class Bank : private MiscFuncs
         bool emptyslot(unsigned int ninstrument) { return emptyslotWithID(currentRootID, currentBankID, ninstrument); }
         void clearslot(unsigned int ninstrument);
         void savetoslot(unsigned int ninstrument, Part *part);
-        bool loadfromslot(unsigned int ninstrument, Part *part);
         void swapslot(unsigned int n1, unsigned int n2);
         void swapbanks(unsigned int firstID, unsigned int secondID);
         bool readOnlyBank(int bankID);
@@ -157,14 +149,9 @@ class Bank : private MiscFuncs
         const RootEntryMap &getRoots();
         const BankEntry &getBank(size_t bankID);
 
-        string getBankFileTitle()
-        {
-            return string("Root #") + asString(currentRootID) + ", Bank #" + asString(currentBankID) + " - " + getBankPath(currentRootID, currentBankID);
-        }
-        string getRootFileTitle()
-        {
-            return string("Root #") + asString(currentRootID) + " - " + getRootPath(currentRootID);
-        }
+        string getBankFileTitle();
+        string getRootFileTitle();
+        
     private:
         bool addtobank(size_t rootID, size_t bankID, int pos, const string filename, const string name);
              // add an instrument to the bank, if pos is -1 try to find a position
