@@ -50,7 +50,6 @@ using namespace std;
 #include "MasterUI.h"
 
 extern void mainRegisterAudioPort(SynthEngine *s, int portnum);
-
 const unsigned short Config::MaxParamsHistory = 25;
 
 static char prog_doc[] =
@@ -58,7 +57,7 @@ static char prog_doc[] =
     "Copyright 2002-2009 Nasca Octavian Paul and others, "
     "Copyright 2009-2011 Alan Calvert, "
     "Copyright 20012-2013 Jeremy Jongepier and others, "
-    "Copyright 20014-2015 Will Godfrey and others";
+    "Copyright 20014-2016 Will Godfrey and others";
 
 const char* argp_program_version = "Yoshimi " YOSHIMI_VERSION;
 
@@ -67,8 +66,10 @@ static struct argp_option cmd_options[] = {
     {"alsa-midi",         'a',  "<device>",   1,  "use alsa midi input" },
     {"define-root",       'D',  "<path>",     0,  "define path to new bank root"},
     {"buffersize",        'b',  "<size>",     0,  "set internal buffer size" },
-    {"show-console",      'c',  NULL,         0,  "show console on startup" },
-    {"no-gui",            'i',  NULL,         0,  "no gui"},
+    {"no-gui",            'i',  NULL,         0,  "disable gui"},
+    {"gui",               'I',  NULL,         0,  "enable gui"},
+    {"no-cmdline",        'c',  NULL,         0,  "disable command line interface"},
+    {"cmdline",           'C',  NULL,         0,  "enable command line interface"},
     {"jack-audio",        'J',  "<server>",   1,  "use jack audio output" },
     {"jack-midi",         'j',  "<device>",   1,  "use jack midi input" },
     {"autostart-jack",    'k',  NULL,         0,  "auto start jack server" },
@@ -92,16 +93,17 @@ Config::Config(SynthEngine *_synth, int argc, char **argv) :
     restoreJackSession(false),
     Samplerate(48000),
     Buffersize(256),
-    Oscilsize(1024),
+    Oscilsize(512),
     runSynth(true),
     showGui(true),
-    showConsole(false),
+    showCLI(true),
     VirKeybLayout(1),
     audioEngine(DEFAULT_AUDIO),
     midiEngine(DEFAULT_MIDI),
     audioDevice("default"),
     midiDevice("default"),
     jackServer("default"),
+    jackMidiDevice("default"),
     startJack(false),
     connectJackaudio(false),
     alsaAudioDevice("default"),
@@ -109,18 +111,24 @@ Config::Config(SynthEngine *_synth, int argc, char **argv) :
     GzipCompression(3),
     Interpolation(0),
     checksynthengines(1),
+    xmlType(0),
     EnableProgChange(1), // default will be inverted
     consoleMenuItem(0),
+    logXMLheaders(0),
+    configChanged(false),
     rtprio(50),
     midi_bank_root(0), // 128 is used as 'disabled'
     midi_bank_C(32),
     midi_upper_voice_C(128),
     enable_part_on_voice_load(1),
+    monitorCCin(false),
     single_row_panel(1),
     NumAvailableParts(NUM_MIDI_CHANNELS),
+    currentPart(0),
     nrpnL(127),
     nrpnH(127),
     nrpnActive(false),
+
     deadObjects(NULL),
     nextHistoryIndex(numeric_limits<unsigned int>::max()),
     sigIntActive(0),
@@ -171,11 +179,10 @@ bool Config::Setup(int argc, char **argv)
     }
     if (!audioDevice.size())
         audioDevice = "default";
-
     switch (midiEngine)
     {
         case jack_midi:
-            midiDevice = string(jackServer);
+            midiDevice = string(jackMidiDevice);
             break;
         case alsa_midi:
             midiDevice = string(alsaMidiDevice);
@@ -204,6 +211,7 @@ bool Config::Setup(int argc, char **argv)
             no_state0: Log("Invalid state file specified for restore " + StateFile);
             return false;
         }
+        Log(StateFile);
     }    
     return true;
 }
@@ -271,6 +279,21 @@ string Config::historyFilename(int index)
     return string();
 }
 
+bool Config::showQuestionOrCmdWarning(string guiQuestion, string cmdLineWarning, bool bForceCmdLinePositive)
+{
+    bool bRet = false;
+    if(showGui)
+    {
+        bRet = fl_choice("%s, ok?", "No", "Yes", "Cancel", guiQuestion.c_str());
+    }
+    else
+    {
+        bRet = bForceCmdLinePositive;//force positive answer if gui is not used (default behavior)
+        cerr << endl << "----- WARNING! -----" << cmdLineWarning << endl << "----- ^^^^^^^^ -----" << endl;
+    }
+    return bRet;
+}
+
 
 string Config::testCCvalue(int cc)
 {
@@ -386,7 +409,7 @@ bool Config::loadConfig(void)
     string homedir = string(getenv("HOME"));
     if (homedir.empty() || !isDirectory(homedir))
         homedir = string("/tmp");
-    ConfigDir = homedir + string("/.config/yoshimi");
+    ConfigDir = homedir + string("/.config/") + YOSHIMI;
     if (!isDirectory(ConfigDir))
     {
         cmd = string("mkdir -p ") + ConfigDir;
@@ -396,46 +419,28 @@ bool Config::loadConfig(void)
             return false;
         }
     }
-    ConfigFile = ConfigDir + string("/yoshimi.config");
-    StateFile = ConfigDir + string("/yoshimi.state");
+    string yoshimi = "/"; // for some reason it doesn't
+    yoshimi += YOSHIMI; // like these as one line here
+    
+    if (synth->getUniqueId() > 0)
+        yoshimi += ("-" + asString(synth->getUniqueId()));
+    string presetDir = ConfigDir + "/presets";
+    if (!isDirectory(presetDir))
+    {
+        cmd = string("mkdir -p ") + presetDir;
+        if ((chk = system(cmd.c_str())) < 0)
+            Log("Create preset directory " + presetDir + " failed, status " + asString(chk));
+    }
+    ConfigFile = ConfigDir + yoshimi + string(".config");
+    StateFile = ConfigDir + yoshimi + string(".state");
     string resConfigFile = ConfigFile;
-    if(synth->getUniqueId() > 0)
-    {
-        resConfigFile += asString(synth->getUniqueId());
-    }
-    if (!isRegFile(resConfigFile) && !isRegFile(ConfigFile))
-    {
-        Log("ConfigFile " + resConfigFile + " not found");
-        Log("Trying for old config file");
-        string oldConfigFile = string(getenv("HOME")) + string("/.yoshimiXML.cfg");
-        if (!isRegFile(oldConfigFile))
-        {
-            Log("Old config file " + resConfigFile + " not found");
-            Log("Trying for ZynAddSubFX config file");
-            oldConfigFile = string(getenv("HOME")) + string("/.zynaddsubfxXML.cfg");
-        }
-        if (isRegFile(oldConfigFile))
-        {
-            Log("Copying old config file " + oldConfigFile + " to new location " + resConfigFile);
-            FILE *oldfle = fopen (oldConfigFile.c_str(), "r");
-            FILE *newfle = fopen (resConfigFile.c_str(), "w");
-            if (oldfle != NULL && newfle != NULL)
-                while (!feof(oldfle))
-                    putc(getc(oldfle), newfle);
-            else
-                Log("Failed to copy old config file " + oldConfigFile + " to " + resConfigFile);
-            if (newfle)
-                fclose(newfle);
-            if (oldfle)
-                fclose(oldfle);
-        }
-    }
 
     bool isok = true;
     if (!isRegFile(resConfigFile) && !isRegFile(ConfigFile))
     {
-        Log("ConfigFile " + resConfigFile + " still not found, will use default settings");
-        saveConfig();
+        Log("ConfigFile " + resConfigFile + " not found, will use default settings");
+        configChanged = true; // give the user the choice
+        //saveConfig();
     }
     else
     {
@@ -475,7 +480,7 @@ bool Config::extractConfigData(XMLwrapper *xml)
         return false;
     }
     Samplerate = xml->getpar("sample_rate", Samplerate, 44100, 96000);
-    Buffersize = xml->getpar("sound_buffer_size", Buffersize, 32, 1024);
+    Buffersize = xml->getpar("sound_buffer_size", Buffersize, 16, 1024);
     Oscilsize = xml->getpar("oscil_size", Oscilsize,
                                         MAX_AD_HARMONICS * 2, 131072);
     GzipCompression = xml->getpar("gzip_compression", GzipCompression, 0, 9);
@@ -483,10 +488,14 @@ bool Config::extractConfigData(XMLwrapper *xml)
     checksynthengines = xml->getpar("check_pad_synth", checksynthengines, 0, 1);
     EnableProgChange = 1 - xml->getpar("ignore_program_change", EnableProgChange, 0, 1); // inverted for Zyn compatibility
     consoleMenuItem = xml->getpar("reports_destination", consoleMenuItem, 0, 1);
+    logXMLheaders = xml->getpar("report_XMLheaders", logXMLheaders, 0, 1);
     VirKeybLayout = xml->getpar("virtual_keyboard_layout", VirKeybLayout, 0, 10);
 
-    // get bank dirs
-    synth->getBankRef().parseConfigFile(xml);
+    audioEngine = (audio_drivers)xml->getpar("audio_engine", audioEngine, no_audio, alsa_audio);
+    midiEngine = (midi_drivers)xml->getpar("midi_engine", midiEngine, no_midi, alsa_midi);
+    showGui = xml->getpar("enable_gui", showGui, 0, 1);
+    showCLI = xml->getpar("enable_CLI", showCLI, 0, 1);
+
 
     // get preset dirs
     int count = 0;
@@ -507,29 +516,33 @@ bool Config::extractConfigData(XMLwrapper *xml)
             "/usr/local/share/yoshimi/presets",
             "/usr/share/zynaddsubfx/presets",
             "/usr/local/share/zynaddsubfx/presets",
-            string(getenv("HOME")) + "/presets",
-            "../presets",
-            "presets"
+            string(getenv("HOME")) + "/.config/yoshimi/presets",
+            localPath("/presets"),
+            "end"
         };
-        const int defaultsCount = 7; // as per presetdirs[] above
-        for (int i = 0; i < defaultsCount; ++i)
-            if (presetdirs[i].size() && isDirectory(presetdirs[i]))
+        int i = 0;
+        while (presetdirs[i] != "end")
+        {
+            if (isDirectory(presetdirs[i]))
                 presetsDirlist[count++] = presetdirs[i];
+            ++ i;
+        }
     }
-
+    
     // alsa settings
     alsaAudioDevice = xml->getparstr("linux_alsa_audio_dev");
     alsaMidiDevice = xml->getparstr("linux_alsa_midi_dev");
 
     // jack settings
     jackServer = xml->getparstr("linux_jack_server");
+    jackMidiDevice = xml->getparstr("linux_jack_midi_dev");
 
     // midi options
     midi_bank_root = xml->getpar("midi_bank_root", midi_bank_root, 0, 128);
     midi_bank_C = xml->getpar("midi_bank_C", midi_bank_C, 0, 128);
     midi_upper_voice_C = xml->getpar("midi_upper_voice_C", midi_upper_voice_C, 0, 128);
     enable_part_on_voice_load = xml->getpar("enable_part_on_voice_load", enable_part_on_voice_load, 0, 1);
-    consoleMenuItem = xml->getpar("enable_console_window", consoleMenuItem, 0, 1);
+//    consoleMenuItem = xml->getpar("enable_console_window", consoleMenuItem, 0, 1);
     single_row_panel = xml->getpar("single_row_panel", single_row_panel, 0, 1);
 
     if (xml->enterbranch("XMZ_HISTORY"))
@@ -549,6 +562,9 @@ bool Config::extractConfigData(XMLwrapper *xml)
         xml->exitbranch();
     }
 
+    // get bank dirs
+    //synth->getBankRef().parseConfigFile(xml);
+    
     xml->exitbranch(); // CONFIGURATION
     return true;
 }
@@ -556,6 +572,7 @@ bool Config::extractConfigData(XMLwrapper *xml)
 
 void Config::saveConfig(void)
 {
+    xmlType = XML_CONFIG;
     XMLwrapper *xmltree = new XMLwrapper(synth);
     if (!xmltree)
     {
@@ -567,14 +584,11 @@ void Config::saveConfig(void)
     GzipCompression = 0;
 
     string resConfigFile = ConfigFile;
-    if(synth->getUniqueId() > 0)
-    {
-        resConfigFile += asString(synth->getUniqueId());
-    }
-    if (!xmltree->saveXMLfile(resConfigFile))
-    {
+
+    if (xmltree->saveXMLfile(resConfigFile))
+        configChanged = false;
+    else
         Log("Failed to save config to " + resConfigFile);
-    }
     GzipCompression = tmp;
 
     delete xmltree;
@@ -585,7 +599,6 @@ void Config::addConfigXML(XMLwrapper *xmltree)
 {
     xmltree->beginbranch("CONFIGURATION");
 
-    xmltree->addparstr("state_file", StateFile);
     xmltree->addpar("sample_rate", Samplerate);
     xmltree->addpar("sound_buffer_size", Buffersize);
     xmltree->addpar("oscil_size", Oscilsize);
@@ -594,9 +607,12 @@ void Config::addConfigXML(XMLwrapper *xmltree)
     xmltree->addpar("check_pad_synth", checksynthengines);
     xmltree->addpar("ignore_program_change", (1 - EnableProgChange));
     xmltree->addpar("reports_destination", consoleMenuItem);
+    xmltree->addpar("report_XMLheaders", logXMLheaders);
     xmltree->addpar("virtual_keyboard_layout", VirKeybLayout);
-
-    synth->getBankRef().saveToConfigFile(xmltree);
+    xmltree->addpar("audio_engine", synth->getRuntime().audioEngine);
+    xmltree->addpar("midi_engine", synth->getRuntime().midiEngine);
+    xmltree->addpar("enable_gui", synth->getRuntime().showGui);
+    xmltree->addpar("enable_CLI", synth->getRuntime().showCLI);
 
     for (int i = 0; i < MAX_PRESETS; ++i)
         if (presetsDirlist[i].size())
@@ -605,17 +621,19 @@ void Config::addConfigXML(XMLwrapper *xmltree)
             xmltree->addparstr("presets_root", presetsDirlist[i]);
             xmltree->endbranch();
         }
-    xmltree->addpar("interpolation", Interpolation);
 
+    xmltree->addpar("interpolation", Interpolation);
+    
     xmltree->addparstr("linux_alsa_audio_dev", alsaAudioDevice);
     xmltree->addparstr("linux_alsa_midi_dev", alsaMidiDevice);
     xmltree->addparstr("linux_jack_server", jackServer);
+    xmltree->addparstr("linux_jack_midi_dev", jackMidiDevice);
 
     xmltree->addpar("midi_bank_root", midi_bank_root);
     xmltree->addpar("midi_bank_C", midi_bank_C);
     xmltree->addpar("midi_upper_voice_C", midi_upper_voice_C);
     xmltree->addpar("enable_part_on_voice_load", enable_part_on_voice_load);
-    xmltree->addpar("enable_console_window", consoleMenuItem);
+//    xmltree->addpar("enable_console_window", consoleMenuItem);
     xmltree->addpar("single_row_panel", single_row_panel);
 
     // Parameters history
@@ -633,12 +651,18 @@ void Config::addConfigXML(XMLwrapper *xmltree)
         }
         xmltree->endbranch();
     }
+    //synth->getBankRef().saveToConfigFile(xmltree);
+
     xmltree->endbranch(); // CONFIGURATION
 }
 
 
 void Config::saveSessionData(string savefile)
 {
+    string ext = ".state";
+    if (savefile.rfind(ext) != (savefile.length() - 6))
+        savefile += ext;
+    synth->getRuntime().xmlType = XML_STATE;
     XMLwrapper *xmltree = new XMLwrapper(synth);
     if (!xmltree)
     {
@@ -659,6 +683,8 @@ bool Config::restoreSessionData(string sessionfile)
 {
     XMLwrapper *xml = NULL;
     bool ok = false;
+    if (sessionfile.size() && !isRegFile(sessionfile))
+        sessionfile += ".state";
     if (!sessionfile.size() || !isRegFile(sessionfile))
     {
         Log("Session file " + sessionfile + " not available", true);
@@ -695,6 +721,8 @@ bool Config::extractRuntimeData(XMLwrapper *xml)
     audioDevice = xml->getparstr("audio_device");
     midiEngine = (midi_drivers)xml->getpar("midi_engine", DEFAULT_MIDI, no_midi, alsa_midi);
     midiDevice = xml->getparstr("midi_device");
+    showGui = xml->getpar("enable_gui", showGui, 0, 1);
+    showCLI = xml->getpar("enable_CLI", showCLI, 0, 1);
     nameTag = xml->getparstr("name_tag");
     CurrentXMZ = xml->getparstr("current_xmz");
     xml->exitbranch();
@@ -709,6 +737,8 @@ void Config::addRuntimeXML(XMLwrapper *xml)
     xml->addparstr("audio_device", audioDevice);
     xml->addpar("midi_engine", midiEngine);
     xml->addparstr("midi_device", midiDevice);
+    xml->addpar("enable_gui", showGui);
+    xml->addpar("enable_CLI", showCLI);
     xml->addparstr("name_tag", nameTag);
     xml->addparstr("current_xmz", CurrentXMZ);
     xml->endbranch();
@@ -717,24 +747,17 @@ void Config::addRuntimeXML(XMLwrapper *xml)
 
 void Config::Log(string msg, bool tostderr)
 {
-    int pos;
     if (showGui && !tostderr && consoleMenuItem)
-    {
-        pos = msg.find(":");
-        if (pos > 1)
-            LogList.push_back(msg.substr(pos + 2));
-        else
-            LogList.push_back(msg);
-    }
+        LogList.push_back(msg);
     else
         cerr << msg << endl;
 }
 
-
+#ifndef YOSHIMI_LV2_PLUGIN
 void Config::StartupReport(MusicClient *musicClient)
 {
     Log(string(argp_program_version));
-    Log("Config: Clientname: " + musicClient->midiClientName());
+    Log("Clientname: " + musicClient->midiClientName());
     string report = "Config: Audio: ";
     switch (audioEngine)
     {
@@ -749,7 +772,7 @@ void Config::StartupReport(MusicClient *musicClient)
     }
     report += (" -> '" + audioDevice + "'");
     Log(report);
-    report = "Config: Midi: ";
+    report = "Midi: ";
     switch (midiEngine)
     {
         case jack_midi:
@@ -765,11 +788,12 @@ void Config::StartupReport(MusicClient *musicClient)
         midiDevice = "default";
     report += (" -> '" + midiDevice + "'");
     Log(report);
-    Log("Config: Oscilsize: " + asString(synth->oscilsize));
-    Log("Config: Samplerate: " + asString(synth->samplerate));
-    Log("Config: Period size: " + asString(synth->buffersize));
+    Log("Oscilsize: " + asString(synth->oscilsize));
+    Log("Samplerate: " + asString(synth->samplerate));
+    Log("Period size: " + asString(synth->buffersize));
 }
 
+#endif
 
 void Config::setRtprio(int prio)
 {
@@ -1033,11 +1057,11 @@ static error_t parse_cmds (int key, char *arg, struct argp_state *state)
 
     switch (key)
     {
-        case 'c': settings->showConsole = true; break;
         case 'N': settings->nameTag = string(arg); break;
         case 'l': settings->paramsLoad = string(arg); break;
         case 'L': settings->instrumentLoad = string(arg); break;
         case 'A':
+            settings->configChanged = true;
             settings->audioEngine = alsa_audio;
             if (arg)
                 settings->audioDevice = string(arg);
@@ -1045,11 +1069,15 @@ static error_t parse_cmds (int key, char *arg, struct argp_state *state)
                 settings->audioDevice = settings->alsaAudioDevice;
             break;
         case 'a':
+            settings->configChanged = true;
             settings->midiEngine = alsa_midi;
             if (arg)
                 settings->midiDevice = string(arg);
+            else
+                settings->midiDevice = string(settings->alsaMidiDevice);
             break;
         case 'b': // messy but I can't think of a better way :(
+            settings->configChanged = true;
             num = Config::string2int(string(arg));
             if (num >= 1024)
                 num = 1024;
@@ -1061,31 +1089,50 @@ static error_t parse_cmds (int key, char *arg, struct argp_state *state)
                 num = 128;
             else if (num >= 64)
                 num = 64;
-            else
+            else if (num >= 32)
                 num = 32;
+            else
+                num = 16;
             settings->Buffersize = num;
             break;
         case 'D':
             if (arg)
                 settings->rootDefine = string(arg);
             break;
+        case 'c':
+            settings->configChanged = true;
+            settings->showCLI = false;
+            break;
+        case 'C':
+            settings->configChanged = true;
+            settings->showCLI = true;
+            break;
         case 'i':
+            settings->configChanged = true;
             settings->showGui = false;
-            settings->showConsole = false;
+            break;
+        case 'I':
+            settings->configChanged = true;
+            settings->showGui = true;
             break;
         case 'J':
+            settings->configChanged = true;
             settings->audioEngine = jack_audio;
             if (arg)
                 settings->audioDevice = string(arg);
             break;
         case 'j':
+            settings->configChanged = true;
             settings->midiEngine = jack_midi;
             if (arg)
                 settings->midiDevice = string(arg);
+            else
+                settings->midiDevice = string(settings->jackMidiDevice);
             break;
         case 'k': settings->startJack = true; break;
         case 'K': settings->connectJackaudio = true; break;
         case 'o':
+            settings->configChanged = true;
             num = Config::string2int(string(arg));
             if (num >= 16384)
                 num = 16384;
@@ -1105,6 +1152,7 @@ static error_t parse_cmds (int key, char *arg, struct argp_state *state)
             settings->Oscilsize = num;
             break;
         case 'R':
+            settings->configChanged = true;
             num = Config::string2int(string(arg));
             if (num >= 96000)
                 num = 96000;
@@ -1135,6 +1183,7 @@ static error_t parse_cmds (int key, char *arg, struct argp_state *state)
         default:
             return ARGP_ERR_UNKNOWN;
     }
+
     return 0;
 }
 
@@ -1190,6 +1239,16 @@ void GuiThreadMsg::processGuiMessages()
             }
         }
             break;
+        case GuiThreadMsg::UpdatePaths:
+        {
+            SynthEngine *synth = ((SynthEngine *)msg->data);
+            MasterUI *guiMaster = synth->getGuiMaster(false);
+            if(guiMaster)
+            {
+                guiMaster->updatepaths(msg->index);
+            }
+        }
+            break;
         case GuiThreadMsg::UpdatePanel:
         {
             SynthEngine *synth = ((SynthEngine *)msg->data);
@@ -1200,6 +1259,17 @@ void GuiThreadMsg::processGuiMessages()
             }
         }
             break;
+        case GuiThreadMsg::UpdatePart:
+        {
+            SynthEngine *synth = ((SynthEngine *)msg->data);
+            MasterUI *guiMaster = synth->getGuiMaster(false);
+            if(guiMaster)
+            {
+                guiMaster->updatepart();
+                guiMaster->updatepanel();
+            }
+        }
+            break;
         case GuiThreadMsg::UpdatePanelItem:
             if(msg->index < NUM_MIDI_PARTS && msg->data)
             {
@@ -1207,7 +1277,7 @@ void GuiThreadMsg::processGuiMessages()
                 MasterUI *guiMaster = synth->getGuiMaster(false);
                 if(guiMaster)
                 {
-                    guiMaster->panellistitem[(msg->index) % NUM_MIDI_CHANNELS]->refresh();
+                    guiMaster->updatelistitem(msg->index);
                     guiMaster->updatepart();
                 }
             }
@@ -1219,6 +1289,7 @@ void GuiThreadMsg::processGuiMessages()
                 MasterUI *guiMaster = synth->getGuiMaster(false);
                 if(guiMaster)
                 {
+                    guiMaster->updatelistitem(msg->index);
                     guiMaster->updatepartprogram(msg->index);
                 }
             }
@@ -1241,6 +1312,40 @@ void GuiThreadMsg::processGuiMessages()
                 mainRegisterAudioPort(synth, msg->index);
             }
             break;
+        case GuiThreadMsg::UpdateBankRootDirs:
+            if(msg->data)
+            {
+                SynthEngine *synth = ((SynthEngine *)msg->data);
+                MasterUI *guiMaster = synth->getGuiMaster(false);
+                if(guiMaster)
+                {
+                    guiMaster->updateBankRootDirs();
+                }
+            }
+            break;
+        case GuiThreadMsg::RescanForBanks:
+            if(msg->data)
+            {
+                SynthEngine *synth = ((SynthEngine *)msg->data);
+                MasterUI *guiMaster = synth->getGuiMaster(false);
+                if(guiMaster && guiMaster->bankui)
+                {
+                    guiMaster->bankui->rescan_for_banks(false);
+                }
+            }
+            break;
+        case GuiThreadMsg::RefreshCurBank:
+            if(msg->data)
+            {
+                SynthEngine *synth = ((SynthEngine *)msg->data);
+                MasterUI *guiMaster = synth->getGuiMaster(false);
+                if(guiMaster && guiMaster->bankui)
+                {
+                    guiMaster->bankui->set_bank_slot();
+                    guiMaster->bankui->refreshmainwindow();
+                }
+            }
+            break;
         default:
             break;
         }
