@@ -588,7 +588,7 @@ void Microtonal::getfromXML(XMLwrapper *xml)
             {
                 if (!xml->enterbranch("KEYMAP", i))
                     continue;
-                Pmapping[i] = xml->getpar127("degree", Pmapping[i]);
+                Pmapping[i] = xml->getpar("degree", Pmapping[i], -1, 127);
                 xml->exitbranch();
             }
             xml->exitbranch();
@@ -600,6 +600,7 @@ void Microtonal::getfromXML(XMLwrapper *xml)
 
 bool Microtonal::saveXML(string filename)
 {
+    synth->getRuntime().xmlType = XML_MICROTONAL;
     XMLwrapper *xml = new XMLwrapper(synth);
 
     xml->beginbranch("MICROTONAL");
@@ -626,7 +627,7 @@ bool Microtonal::loadXML(string filename)
     }
     if (!xml->enterbranch("MICROTONAL"))
     {
-        synth->getRuntime().Log("Microtonal: " + filename + " is not a scale file");
+        synth->getRuntime().Log(filename + " is not a scale file");
         return false;
     }
     getfromXML(xml);
