@@ -26,6 +26,7 @@
 
 #include <cstring>
 #include <cmath>
+#include <semaphore.h>
 
 using namespace std;
 
@@ -119,7 +120,7 @@ void Part::defaults(void)
     Penabled = 0;
     Pminkey = 0;
     Pmaxkey = 127;
-    Pnoteon = 1;
+//    Pnoteon = 1;
     Ppolymode = 1;
     Plegatomode = 0;
     setVolume(96);
@@ -178,7 +179,8 @@ void Part::defaultsinstrument(void)
 // Cleanup the part
 void Part::cleanup(void)
 {
-    Mute();
+    int enablepart = Penabled;
+    Penabled = 0;
     for (int k = 0; k < POLIPHONY; ++k)
         KillNotePos(k);
     memset(partoutl, 0, synth->bufferbytes);
@@ -195,7 +197,7 @@ void Part::cleanup(void)
         memset(partfxinputr[n], 0, synth->bufferbytes);
 
     }
-    Unmute();
+    Penabled = enablepart;
 }
 
 
@@ -235,7 +237,8 @@ Part::~Part()
 // Note On Messages
 void Part::NoteOn(int note, int velocity, int masterkeyshift)
 {
-    if (!Pnoteon || note < Pminkey || note > Pmaxkey)
+//    if (!Pnoteon || note < Pminkey || note > Pmaxkey)
+    if (note < Pminkey || note > Pmaxkey)
         return;
 
     // Legato and MonoMem used vars:
@@ -331,7 +334,7 @@ void Part::NoteOn(int note, int velocity, int masterkeyshift)
     if (pos == -1)
     {
         // test
-        synth->getRuntime().Log("Too may notes - notes > poliphony, PartNoteOn()");
+        synth->getRuntime().Log("Too many notes - notes > poliphony");
     }
     else
     {
@@ -362,10 +365,13 @@ void Part::NoteOn(int note, int velocity, int masterkeyshift)
         else
             notebasefreq = microtonal->getNoteFreq(note);
 
-        if (Pfrand > 0.002)  // effective range 0.005 to 0.1
-        {
-          notebasefreq *= (1 + ((synth->numRandom() - 0.5f) * Pfrand));
-        }
+        // Humanise
+        // cout << "\n" << notebasefreq << endl;
+        if (!Pdrummode && Pfrand >= 1) // otherwise 'off'
+            // this is an approximation to keep the math simple and is
+            // about 1 cent out at 50 cents
+            notebasefreq *= (1.0f + ((synth->numRandom() - 0.5f) * Pfrand * 0.00115f));
+        // cout << notebasefreq << endl;
 
         // Portamento
         if (oldfreq < 1.0f)
@@ -615,7 +621,7 @@ void Part::NoteOn(int note, int velocity, int masterkeyshift)
         }
     }
 
-    // this only relase the keys if there is maximum number of keys allowed
+    // this only release the keys if there is maximum number of keys allowed
     setkeylimit(Pkeylimit);
 }
 
@@ -768,9 +774,9 @@ void Part::MonoMemRenote(void)
 {
     unsigned char mmrtempnote = monomemnotes.back(); // Last list element.
     monomemnotes.pop_back(); // We remove it, will be added again in NoteOn(...).
-    if (Pnoteon == 0)
+/*    if (Pnoteon == 0)
         RelaseNotePos(lastpos);
-    else
+    else*/
         NoteOn(mmrtempnote, monomem[mmrtempnote].velocity,
                monomem[mmrtempnote].mkeyshift);
 }
@@ -1088,14 +1094,14 @@ void Part::setkititemstatus(int kititem, int Penabled_)
 
 void Part::add2XMLinstrument(XMLwrapper *xml)
 {
-    if (Pname == "Simple Sound")
-        return;
     xml->beginbranch("INFO");
     xml->addparstr("name", Pname);
     xml->addparstr("author", info.Pauthor);
     xml->addparstr("comments", info.Pcomments);
     xml->addpar("type",info.Ptype);
     xml->endbranch();
+    if (Pname == "Simple Sound")
+        return;
 
 
     xml->beginbranch("INSTRUMENT_KIT");
@@ -1179,10 +1185,11 @@ void Part::add2XML(XMLwrapper *xml)
     xml->addpar("velocity_sensing", Pvelsns);
     xml->addpar("velocity_offset", Pveloffs);
 
-    xml->addparbool("note_on", Pnoteon);
+//    xml->addparbool("note_on", Pnoteon);
     xml->addparbool("poly_mode", Ppolymode);
     xml->addpar("legato_mode", Plegatomode);
     xml->addpar("key_limit", Pkeylimit);
+    xml->addpar("random_detune", Pfrand);
     xml->addpar("destination", Paudiodest);
 
     xml->beginbranch("INSTRUMENT");
@@ -1197,6 +1204,7 @@ void Part::add2XML(XMLwrapper *xml)
 
 bool Part::saveXML(string filename)
 {
+    synth->getRuntime().xmlType = XML_INSTRUMENT;
     XMLwrapper *xml = new XMLwrapper(synth);
     if (!xml)
     {
@@ -1235,11 +1243,9 @@ int Part::loadXMLinstrument(string filename)
         synth->getRuntime().Log(filename + " is not an instrument file");
         return 0;
     }
-    Mute();
     defaultsinstrument();
     getfromXMLinstrument(xml);
     applyparameters();
-    Unmute();
     xml->exitbranch();
     delete xml;
     if (synth->getRuntime().SimpleCheck)
@@ -1271,7 +1277,12 @@ void Part::getfromXMLinstrument(XMLwrapper *xml)
         xml->exitbranch();
     }
 
-    if (xml->enterbranch("INSTRUMENT_KIT"))
+    if (!xml->enterbranch("INSTRUMENT_KIT"))
+    {
+        defaultsinstrument();
+        return;
+    }
+    else
     {
         Pkitmode = xml->getpar127("kit_mode", Pkitmode);
         Pdrummode = xml->getparbool("drum_mode", Pdrummode);
@@ -1350,7 +1361,7 @@ void Part::getfromXML(XMLwrapper *xml)
     Pvelsns = xml->getpar127("velocity_sensing", Pvelsns);
     Pveloffs = xml->getpar127("velocity_offset", Pveloffs);
 
-    Pnoteon = xml->getparbool("note_on", Pnoteon);
+//    Pnoteon = xml->getparbool("note_on", Pnoteon);
     Ppolymode = xml->getparbool("poly_mode", Ppolymode);
     Plegatomode = xml->getparbool("legato_mode", Plegatomode); // older versions
     if (!Plegatomode)
@@ -1364,6 +1375,9 @@ void Part::getfromXML(XMLwrapper *xml)
     {
         Pkeylimit = POLIPHONY - 20;
     }
+    Pfrand = xml->getpar127("random_detune", Pfrand);
+    if (Pfrand > 50)
+        Pfrand = 50;
     setDestination(xml->getpar127("destination", Paudiodest));
     
     if (xml->enterbranch("INSTRUMENT"))
