@@ -109,13 +109,16 @@ class XMLwrapper : private MiscFuncs
         bool minimal; // false if all parameters will be stored (used only for clipboard)
 
         struct {
+            unsigned char ADDsynth_used;
+            unsigned char SUBsynth_used;
             unsigned char PADsynth_used;
         } information;
 
         // opens a file and parse only the "information" data on it
         // returns "true" if all went ok or "false" on errors
         bool checkfileinformation(const string& filename);
-
+        bool slowinfosearch(char *xmldata);
+        
     private:
         char *doloadfile(const string& filename);
 
@@ -147,6 +150,8 @@ class XMLwrapper : private MiscFuncs
         struct {
             int major; // settings format version
             int minor;
+            int y_major;
+            int y_minor;
         } xml_version;
 
         SynthEngine *synth;
