@@ -80,7 +80,8 @@ class ADnote : public Carcass, private SynthHelper, private Float2Int
         void computeVoiceOscillatorPitchModulation(int nvoice);
 
         void computeVoiceNoise(int nvoice);
-
+        void ComputeVoicePinkNoise(int nvoice);
+        
         void fadein(float *smps);
 
 
@@ -108,6 +109,8 @@ class ADnote : public Carcass, private SynthHelper, private Float2Int
 
             Envelope *AmpEnvelope;
             LFO      *AmpLfo;
+            
+            float Fadein_adjustment;
             struct {
                 int      Enabled;
                 float initialvalue, dt, t;
@@ -152,6 +155,11 @@ class ADnote : public Carcass, private SynthHelper, private Float2Int
             Envelope *AmpEnvelope;
             LFO      *AmpLfo;
 
+            struct {
+                int   Enabled;
+                float initialvalue, dt, t;
+            } Punch;
+
             // Filter parameters
             Filter   *VoiceFilterL;
             Filter   *VoiceFilterR;
@@ -176,6 +184,9 @@ class ADnote : public Carcass, private SynthHelper, private Float2Int
         // Internal values of the note and of the voices
         float time; // time from the start of the note
 
+        //pinking filter (Paul Kellet)
+        float pinking[NUM_VOICES][14];
+
         int unison_size[NUM_VOICES]; // the size of unison for a single voice
 
         float unison_stereo_spread[NUM_VOICES]; // stereo spread of subvoices (0.0=mono,1.0=max)
