@@ -33,10 +33,12 @@
 #include "Params/Presets.h"
 #include "Synth/Resonance.h"
 
+class SynthEngine;
+
 class OscilGen : public Presets, private WaveShapeSamples
 {
     public:
-        OscilGen(FFTwrapper *fft_,Resonance *res_);
+        OscilGen(FFTwrapper *fft_,Resonance *res_, SynthEngine *_synth);
         ~OscilGen();
 
         void prepare();
@@ -62,7 +64,7 @@ class OscilGen : public Presets, private WaveShapeSamples
 
         // Make a new random seed for Amplitude Randomness -
         //   should be called every noteon event
-        inline void newrandseed(void) { randseed = (unsigned int)random(); };
+        inline void newrandseed(void) { randseed = (unsigned int)random(); }
 
         // Parameters
 
@@ -203,13 +205,13 @@ class OscilGen : public Presets, private WaveShapeSamples
 
         float random_0_1;
         int32_t random_result;
-        static struct random_data random_buf;
-        static char random_state[];
+        struct random_data random_buf;
+        char random_state[256];
 
         float harmonic_random_0_1;
         int32_t harmonic_random_result;
-        static struct random_data harmonic_random_buf;
-        static char harmonic_random_state[];
+        struct random_data harmonic_random_buf;
+        char harmonic_random_state[256];
 };
 
 
