@@ -35,12 +35,14 @@ class Controller;
 class Envelope;
 class Filter;
 
+class SynthEngine;
+
 class SUBnote : public Carcass, private SynthHelper
 {
     public:
         SUBnote(SUBnoteParameters *parameters, Controller *ctl_,
                 float freq, float velocity, int portamento_,
-                int midinote, bool besilent);
+                int midinote, bool besilent, SynthEngine *_synth);
         ~SUBnote();
 
         void SUBlegatonote(float freq, float velocity,
@@ -49,7 +51,7 @@ class SUBnote : public Carcass, private SynthHelper
         int noteout(float *outl,float *outr); // note output, return 0 if the
                                               // note is finished
         void relasekey(void);
-        bool finished(void) { return !NoteEnabled; };
+        bool finished(void) { return !NoteEnabled; }
 
         bool ready; // if I can get the sampledata
 
@@ -106,6 +108,7 @@ class SUBnote : public Carcass, private SynthHelper
         float computerolloff(float freq);
         void computefiltercoefs(bpfilter &filter, float freq, float bw, float gain);
         void filter(bpfilter &filter, float *smps);
+        void filterVarRun(bpfilter &filter, float *smps);
 
         bpfilter *lfilter;
         bpfilter *rfilter;
@@ -147,6 +150,9 @@ class SUBnote : public Carcass, private SynthHelper
         const float log_0_001;   // logf(0.001);
         const float log_0_0001;  // logf(0.0001);
         const float log_0_00001; // logf(0.00001);
+
+        SynthEngine *synth;
+        int filterStep;
 };
 
 #endif
